@@ -18,7 +18,8 @@ Bed2Fa::Bed2Fa(const string &dbFile,
                const string &bedFile, const string &fastaOutFile,
                bool useFasta, bool useStrand, 
                bool useBlocks, bool useFullHeader,
-               bool useBedOut, bool useName, bool useNamePlus) :
+               bool useBedOut, bool useName, 
+               bool useNamePlus, bool useNameOnly) :
     _dbFile(dbFile),
     _bedFile(bedFile),
     _fastaOutFile(fastaOutFile),
@@ -28,7 +29,8 @@ Bed2Fa::Bed2Fa(const string &dbFile,
     _useFullHeader(useFullHeader),
     _useBedOut(useBedOut),
     _useName(useName),
-    _useNamePlus(useNamePlus)
+    _useNamePlus(useNamePlus),
+    _useNameOnly(useNameOnly)
 {
     _bed = new BedFile(_bedFile);
 
@@ -74,15 +76,15 @@ void Bed2Fa::ReportDNA(const BED &bed, string &dna) {
     }
     else {
         ostringstream header;
-        if (_useName)
-        {
-            header << bed.name;
-        }
-        else if (_useNamePlus) 
+        if (_useName || _useNamePlus)
         {
             header << bed.name << "::" << bed.chrom << ":" 
                    << bed.start << "-" << bed.end;
         }
+        else if (_useNameOnly)
+        {
+            header << bed.name;
+        }
         else 
         {
             header << bed.chrom << ":" 
@@ -101,8 +103,6 @@ void Bed2Fa::ReportDNA(const BED &bed, string &dna) {
     }
 }
 
-
-
 //******************************************************************************
 // ExtractDNA
 //******************************************************************************
@@ -133,7 +133,7 @@ void Bed2Fa::ExtractDNA() {
             // make sure we are extracting >= 1 bp
             if (bed.zeroLength == false) {
     
-                size_t seqLength = fr->sequenceLength(bed.chrom);
+                CHRPOS seqLength = fr->sequenceLength(bed.chrom);
                 // seqLength > 0 means chrom was found in index.
                 // seqLength == 0 otherwise.
                 if (seqLength) {
@@ -141,7 +141,7 @@ void Bed2Fa::ExtractDNA() {
                     // the end of the chromosome.
                     if ( (bed.start <= seqLength) && (bed.end <= seqLength) ) 
                     {
-                        int length = bed.end - bed.start;
+                        CHRPOS length = bed.end - bed.start;
                         if(_useBlocks){
                             // vec to store the discrete BED "blocks"
                             bedVector bedBlocks;  
