@@ -50,7 +50,7 @@ BedGenomeCoverage::BedGenomeCoverage(string bedFile, string genomeFile,
 
 
     if (_bamInput == false) {
-        _genome = new GenomeFile(genomeFile);
+        _genome = new NewGenomeFile(genomeFile);
     }
 
     PrintTrackDefinitionLine();
@@ -80,8 +80,10 @@ void BedGenomeCoverage::PrintTrackDefinitionLine()
 
 
 BedGenomeCoverage::~BedGenomeCoverage(void) {
-    delete _bed;
-    delete _genome;
+    if (_bamInput == false) {
+        delete _bed;
+        delete _genome;
+    }
 }
 
 
@@ -99,14 +101,14 @@ void BedGenomeCoverage::StartNewChrom(const string& newChrom) {
         ReportChromCoverage(_currChromCoverage, _currChromSize,
                 _currChromName, _currChromDepthHist);
     }
-
     // empty the previous chromosome and reserve new
     std::vector<DEPTH>().swap(_currChromCoverage);
 
     if (_visitedChromosomes.find(newChrom) != _visitedChromosomes.end()) {
-        cerr << "Input error: Chromosome " << _currChromName
-             << " found in non-sequential lines. This suggests that the input file is not sorted correctly." << endl;
-
+        cerr << "Input error: Chromosome "
+             << _currChromName
+             << " found in non-sequential lines. This suggests that the input file is not sorted correctly." 
+             << endl;
     }
     _visitedChromosomes.insert(newChrom);
 
@@ -118,15 +120,18 @@ void BedGenomeCoverage::StartNewChrom(const string& newChrom) {
     if (_currChromSize >= 0)
         _currChromCoverage.resize(_currChromSize);
     else {
-        cerr << "Input error: Chromosome " << _currChromName << " found in your input file but not in your genome file." << endl;
+        cerr << "Input error: Chromosome " 
+             << _currChromName 
+             << " found in your input file but not in your genome file." 
+             << endl;
         exit(1);
     }
 }
 
 
-void BedGenomeCoverage::AddCoverage(int start, int end) {
+void BedGenomeCoverage::AddCoverage(CHRPOS start, CHRPOS end) {
     // process the first line for this chromosome.
-    // make sure the coordinates fit within the chrom
+    // make sure the coordinates fit within the chrom 
     if (start < _currChromSize)
         _currChromCoverage[start].starts++;
     if (end >= 0 && end < _currChromSize)
@@ -159,11 +164,17 @@ void BedGenomeCoverage::CoverageBed() {
         if (_bed->_status == BED_VALID) {
             if (_filterByStrand == true) {
                 if (a.strand.empty()) {
-                    cerr << "Input error: Interval is missing a strand value on line " << _bed->_lineNum << "." <<endl;
+                    cerr << "Input error: Interval is missing a strand value on line " 
+                         << _bed->_lineNum 
+                         << "." <<endl;
                     exit(1);
                 }
                 if ( ! (a.strand == "-" || a.strand == "+") ) {
-                    cerr << "Input error: Invalid strand value (" << a.strand << ") on line " << _bed->_lineNum << "." << endl;
+                    cerr << "Input error: Invalid strand value (" 
+                         << a.strand << ") on line " 
+                         << _bed->_lineNum 
+                         << "." 
+                         << endl;
                     exit(1);
                 }
                 // skip if the strand is not what the user requested.
@@ -181,15 +192,16 @@ void BedGenomeCoverage::CoverageBed() {
                 AddBlockedCoverage(bedBlocks);
             }
             else if (_only_5p_end) {
-                int pos = ( a.strand=="+" ) ? a.start : a.end-1;
+                CHRPOS pos = ( a.strand=="+" ) ? a.start : a.end-1;
                 AddCoverage(pos,pos);
             }
             else if (_only_3p_end) {
-                int pos = ( a.strand=="-" ) ? a.start : a.end-1;
+                CHRPOS pos = ( a.strand=="-" ) ? a.start : a.end-1;
                 AddCoverage(pos,pos);
             }
-            else
+            else {
                 AddCoverage(a.start, a.end-1);
+            }
         }
     }
     _bed->Close();
@@ -219,7 +231,7 @@ void BedGenomeCoverage::PrintEmptyChromosomes()
             _currChromSize = _genome->getChromSize(_currChromName);
             std::vector<DEPTH>().swap(_currChromCoverage);
             _currChromCoverage.resize(_currChromSize);
-            for (int i = 0; i < _currChromSize; ++i)
+            for (CHRPOS i = 0; i < _currChromSize; ++i)
             {
                 _currChromCoverage[i].starts = 0;
                 _currChromCoverage[i].ends = 0;
@@ -245,7 +257,9 @@ void BedGenomeCoverage::CoverageBam(string bamFile) {
     // open the BAM file
     BamReader reader;
     if (!reader.Open(bamFile)) {
-        cerr << "Failed to open BAM file " << bamFile << endl;
+        cerr << "Failed to open BAM file " 
+             << bamFile 
+             << endl;
         exit(1);
     }
 
@@ -254,7 +268,7 @@ void BedGenomeCoverage::CoverageBam(string bamFile) {
     RefVector refs = reader.GetReferenceData();
 
     // load the BAM header references into a BEDTools "genome file"
-    _genome = new GenomeFile(refs);
+    _genome = new NewGenomeFile(refs);
     // convert each aligned BAM entry to BED
     // and compute coverage on B
     BamAlignment bam;
@@ -342,11 +356,11 @@ void BedGenomeCoverage::CoverageBam(string bamFile) {
             AddBlockedCoverage(bedBlocks);
         }
         else if (_only_5p_end) {
-            int pos = ( !bam.IsReverseStrand() ) ? start : end;
+            CHRPOS pos = ( !bam.IsReverseStrand() ) ? start : end;
             AddCoverage(pos,pos);
         }
         else if (_only_3p_end) {
-            int pos = ( bam.IsReverseStrand() ) ? start : end;
+            CHRPOS pos = ( bam.IsReverseStrand() ) ? start : end;
             AddCoverage(pos,pos);
         }
     }
@@ -365,12 +379,12 @@ void BedGenomeCoverage::CoverageBam(string bamFile) {
 }
 
 
-void BedGenomeCoverage::ReportChromCoverage(const vector<DEPTH> &chromCov, const int &chromSize, const string &chrom, chromHistMap &chromDepthHist) {
+void BedGenomeCoverage::ReportChromCoverage(const vector<DEPTH> &chromCov, const CHRPOS &chromSize, const string &chrom, chromHistMap &chromDepthHist) {
 
     if (_eachBase) {
         int depth = 0; // initialize the depth
-        int offset = (_eachBaseZeroBased)?0:1;
-        for (int pos = 0; pos < chromSize; pos++) {
+        CHRPOS offset = (_eachBaseZeroBased)?0:1;
+        for (CHRPOS pos = 0; pos < chromSize; pos++) {
 
             depth += chromCov[pos].starts;
             // report the depth for this position.
@@ -386,7 +400,7 @@ void BedGenomeCoverage::ReportChromCoverage(const vector<DEPTH> &chromCov, const
 
         int depth = 0; // initialize the depth
 
-        for (int pos = 0; pos < chromSize; pos++) {
+        for (CHRPOS pos = 0; pos < chromSize; pos++) {
 
             depth += chromCov[pos].starts;
 
@@ -420,7 +434,7 @@ void BedGenomeCoverage::ReportGenomeCoverage(chromHistMap &chromDepthHist) {
     // get the list of chromosome names in the genome
     vector<string> chromList = _genome->getChromList();
 
-    unsigned int genomeSize = 0;
+    CHRPOS genomeSize = 0;
     vector<string>::const_iterator chromItr = chromList.begin();
     vector<string>::const_iterator chromEnd = chromList.end();
     for (; chromItr != chromEnd; ++chromItr) {
@@ -441,7 +455,7 @@ void BedGenomeCoverage::ReportGenomeCoverage(chromHistMap &chromDepthHist) {
         string chrom = chromIt->first;
         for (histMap::iterator depthIt = chromDepthHist[chrom].begin(); depthIt != chromDepthHist[chrom].end(); ++depthIt) {
             int depth = depthIt->first;
-            unsigned int numBasesAtDepth = depthIt->second;
+            CHRPOS numBasesAtDepth = depthIt->second;
             genomeHist[depth] += numBasesAtDepth;
         }
     }
@@ -451,7 +465,7 @@ void BedGenomeCoverage::ReportGenomeCoverage(chromHistMap &chromDepthHist) {
     // the entire genome that are at said depth.
     for (histMap::iterator genomeDepthIt = genomeHist.begin(); genomeDepthIt != genomeHist.end(); ++genomeDepthIt) {
         int depth = genomeDepthIt->first;
-        unsigned int numBasesAtDepth = genomeDepthIt->second;
+        CHRPOS numBasesAtDepth = genomeDepthIt->second;
 
         cout << "genome" << "\t" << depth << "\t" << numBasesAtDepth << "\t"
             << genomeSize << "\t" << (float) ((float)numBasesAtDepth / (float)genomeSize) << endl;
@@ -459,13 +473,13 @@ void BedGenomeCoverage::ReportGenomeCoverage(chromHistMap &chromDepthHist) {
 }
 
 
-void BedGenomeCoverage::ReportChromCoverageBedGraph(const vector<DEPTH> &chromCov, const int &chromSize, const string &chrom) {
+void BedGenomeCoverage::ReportChromCoverageBedGraph(const vector<DEPTH> &chromCov, const CHRPOS &chromSize, const string &chrom) {
 
     int depth = 0; // initialize the depth
-    int lastStart = -1;
+    CHRPOS lastStart = -1;
     int lastDepth = -1;
 
-    for (int pos = 0; pos < chromSize; pos++) {
+    for (CHRPOS pos = 0; pos < chromSize; pos++) {
         depth += chromCov[pos].starts;
 
         if (depth != lastDepth) {
@@ -474,7 +488,18 @@ void BedGenomeCoverage::ReportChromCoverageBedGraph(const vector<DEPTH> &chromCo
             // (1) depth>0 (the default running mode),
             // (2) depth==0 and the user requested to print zero covered regions (_bedGraphAll)
             if ( (lastDepth != -1) && (lastDepth > 0 || _bedGraphAll) ) {
-                cout << chrom << "\t" << lastStart << "\t" << pos << "\t" << lastDepth * _scale << endl;
+
+                if (lastDepth >= _max) {
+                    lastDepth = _max;
+                }
+                cout << chrom 
+                     << "\t" 
+                     << lastStart 
+                     << "\t" 
+                     << pos 
+                     << "\t" 
+                     << lastDepth * _scale 
+                     << endl;
             }
             //Set current position as the new interval start + depth
             lastDepth = depth;
@@ -487,6 +512,13 @@ void BedGenomeCoverage::ReportChromCoverageBedGraph(const vector<DEPTH> &chromCo
     }
     //Print information about the last position
     if ( (lastDepth != -1) && (lastDepth > 0 || _bedGraphAll) ) {
-        cout << chrom << "\t" << lastStart << "\t" << chromSize << "\t" << lastDepth * _scale << endl;
+        cout << chrom 
+             << "\t" 
+             << lastStart 
+             << "\t" 
+             << chromSize 
+             << "\t" 
+             << lastDepth * _scale 
+             << endl;
     }
 }
