@@ -51,7 +51,7 @@ void BedShift::AddShift(BED &bed) {
 
   CHRPOS chromSize = (CHRPOS)_genome->getChromSize(bed.chrom);
 
-  double shift;
+  CHRPOS shift;
 
   if (bed.strand == "-") {
     shift = _shiftMinus;
