@@ -54,9 +54,9 @@ void BedSlop::SlopBed() {
                 AddSlop(bedEntry);
             }
             else {
-               l = _leftSlop;	
+               l = _leftSlop;   
                _leftSlop  = _leftSlop * (float)bedEntry.size();
-               r = _rightSlop;	
+               r = _rightSlop;  
                _rightSlop = _rightSlop * (float)bedEntry.size();
                AddSlop(bedEntry);
                _rightSlop = r;
@@ -67,72 +67,32 @@ void BedSlop::SlopBed() {
    }
    _bed->Close();
 }
-
-
+static inline long _normalize_coord(long size, long pos) {
+	if(pos < 0) return 0;
+	if(size >= 0 && pos > size) return size;
+	return pos;
+}
 void BedSlop::AddSlop(BED &bed) {
 
     // special handling if the BED entry is on the negative
     // strand and the user cares about strandedness.
     CHRPOS chromSize = (CHRPOS)_genome->getChromSize(bed.chrom);
 
-    if ( (_forceStrand) && (bed.strand == "-") ) {
-        if ( ((int)bed.start - (long)_rightSlop) >= 0 ) {
-          // if the _rightSlop is negative and pushes bed.start to be > chromSize 0, set to chromSize
-            if (((int)bed.start - (long)_rightSlop) >= chromSize && _rightSlop < 0) {
-                bed.start = chromSize;  
-            }
-            else {
-              bed.start = bed.start - (long)_rightSlop;
-            }
-        }
-        else {
-            bed.start = 0;
-        }
-        if ( ((int)bed.end + (long)_leftSlop) <= chromSize ) {
-            // if the _leftSlop is negative and pushes bed.end to be < 0, set to 0
-            if((((int)bed.end + (int)_leftSlop) <= 0) && _leftSlop < 0) {
-                bed.end = 0;
-            }
-            else {
-              bed.end = bed.end + (int)_leftSlop;
-            }
-        }    
-        else {
-            
-            bed.end = chromSize;
-        }
-    }
-    else {
-        if ( ((int)bed.start - (long)_leftSlop) >= 0 ) {
-          // checking negative condition for _leftSlop
-            if( ((int)bed.start - (long)_leftSlop) >= chromSize && _leftSlop < 0)
-            {
-              bed.start = chromSize;
-            }
-            else {
-              bed.start = bed.start - (int)_leftSlop;
-            }
-        }
-        else {
-            bed.start = 0;
-        }
+	if(chromSize < 0) {
+		cerr << "* Input error: Chromosome " << bed.chrom << " doesn't present in the .genome file. *" << endl;
+		exit(1);
+	}
+
+	bool should_swap = _forceStrand && bed.strand == "-";
+	long left_slop = should_swap ? (long)_rightSlop : (long)_leftSlop;
+	long right_slop = should_swap ? (long)_leftSlop : (long)_rightSlop;
+
+	bed.start -= left_slop;
+	bed.end += right_slop;
+
+	bed.start = _normalize_coord(chromSize, bed.start);
+	bed.end = _normalize_coord(chromSize, bed.end);
 
-        if ( ((int)bed.end + (long)_rightSlop) <= chromSize )
-        {
-          // checking negative _rightSlop condition
-            if( ((int)bed.end + (long)_rightSlop) <= 0 && _rightSlop < 0) {
-                bed.end = 0;
-              }
-              else {
-                bed.end = bed.end + (int)_rightSlop;            
-              }
-        }
-        else
-        {
-          
-                bed.end = chromSize;                
-        }
-    }
     //checking edge case and adjusting
     if( bed.start == bed.end && bed.start == chromSize ){
       bed.start -= 1;
@@ -142,7 +102,7 @@ void BedSlop::AddSlop(BED &bed) {
       bed.end += 1;
     }
     else if(bed.start > bed.end){
-      int temp = bed.start;
+      CHRPOS temp = bed.start;
       bed.start = bed.end;
       bed.end = temp;
     }
