@@ -55,7 +55,7 @@ bool SingleLineDelimTextFileReader::readEntry()
 
 	//check to make sure line has something besides whitespace.
 	bool hasNonSpace = false;
-	int lineLen = _sLine.size();
+	int lineLen = (int)_sLine.size();
 	for (int i=0; i < lineLen; i++) {
 		if (!isspace(_sLine[i])) {
 			hasNonSpace = true;
@@ -78,13 +78,13 @@ bool SingleLineDelimTextFileReader::readEntry()
 
 
 void SingleLineDelimTextFileReader::getField(int fieldNum, string &str) const {
-	int startPos = _delimPositions[fieldNum] +1;
-	int endPos = _delimPositions[fieldNum+1];
+	CHRPOS startPos = _delimPositions[fieldNum] +1;
+	CHRPOS endPos = _delimPositions[fieldNum+1];
 	str.assign(_sLine.c_str() + startPos, endPos - startPos);
 }
 
 
-void SingleLineDelimTextFileReader::getField(int fieldNum, int &val) const {
+void SingleLineDelimTextFileReader::getField(int fieldNum, CHRPOS &val) const {
 	string temp;
 	getField(fieldNum, temp);
 	val = str2chrPos(temp.c_str());
@@ -148,7 +148,7 @@ bool SingleLineDelimTextFileReader::findDelimiters() {
 	return true;
 }
 
-int SingleLineDelimTextFileReader::getVcfSVlen() {
+CHRPOS SingleLineDelimTextFileReader::getVcfSVlen() {
 	// tokenize the INFO field
 	string info_str;
 	vector<string> infofields;
@@ -166,7 +166,7 @@ int SingleLineDelimTextFileReader::getVcfSVlen() {
         //SVLEN->100
         if (keytoval.size() == 2) {
         	if (keytoval.at(0) == "SVLEN") {
-        		vector<int> svlens;
+        		vector<CHRPOS> svlens;
         		Tokenize(keytoval.at(1), svlens, ',');
         		// are the multiple SVLENS?
         		if (svlens.size() == 1) {
@@ -174,7 +174,7 @@ int SingleLineDelimTextFileReader::getVcfSVlen() {
         		}
         		else {
         			// return the abs_max SVLEN
-        			int max_len = *max_element(svlens.begin(),svlens.end(), abs_cmp);
+        			CHRPOS max_len = *max_element(svlens.begin(),svlens.end(), abs_cmp);
         			return abs(max_len);
         		}
         	}
@@ -182,7 +182,7 @@ int SingleLineDelimTextFileReader::getVcfSVlen() {
         		string start_str;
         		getField(1, start_str);
         		// length is END - POS + 1
-        		return str2chrPos(keytoval.at(1)) - str2chrPos(start_str) + 1;
+        		return (int)(str2chrPos(keytoval.at(1)) - str2chrPos(start_str) + 1);
         	}
 		}
     }
