@@ -35,7 +35,7 @@ void Bed6Interval::print(string &outBuf) const
 	outBuf.append(_strand);
 }
 
-void Bed6Interval::print(string &outBuf, int start, int end) const
+void Bed6Interval::print(string &outBuf, CHRPOS start, CHRPOS end) const
 {
 	Bed3Interval::print(outBuf, start, end);
 	outBuf.append("\t");
