@@ -260,4 +260,30 @@ $BT genomecov -ibam chip.bam -bg -fs 100 > obs
 check obs exp
 rm obs exp
 
+rm one_block.bam two_blocks.bam three_blocks.bam sam-w-del.bam pair-chip.bam chip.bam
+
+##################################################################
+#  Make sure empty bam doesn't cause failure
+##################################################################
+echo -e "    genomecov.t16...\c"
+echo \
+"1	0	100	100	1
+2	0	100	100	1
+3	0	100	100	1
+genome	0	300	300	1" > exp
+$BT genomecov -ibam empty.bam > obs
+check obs exp
+rm obs exp
+
+##################################################################
+#  Make sure empty CRAM doesn't cause failure
+##################################################################
+echo -e "    genomecov.t17...\c"
+echo \
+"chr1	0	50000	50000	1
+genome	0	50000	50000	1" > exp
+CRAM_REFERENCE=test_ref.fa $BT genomecov -ibam empty.cram > obs
+check obs exp
+rm obs exp
+
 [[ $FAILURES -eq 0 ]] || exit 1;
